<?php
/**
 * This Software is the property of Data Development and is protected
 * by copyright law - it is NOT Freeware.
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 * http://www.shopmodule.com
 *
 * @copyright (C) D3 Data Development (Inh. Thomas Dartsch)
 * @author        D3 Data Development <support@shopmodule.com>
 * @link          http://www.oxidmodule.com
 * modified       F.M. 20170306 POSeidon Digital GmbH: Added DateTime in echo for better logging
 */

ini_set('display_errors', 1);
ini_set('error_reporting', E_ALL);

define("OX_IS_ADMIN", true);

/**
 * Returns shop base path.
 *
 * @return string
 */
function getShopBasePath()
{
    return dirname(__FILE__) . '/../../../../';
}

require_once getShopBasePath() . "/bootstrap.php";

// Get formatted date & time for logging.
$getD3ImportTimestamp = function ()
{
    return date("Y-m-d H:i:s: ");
};

if (false == isset($argv[1])) {
    echo "No arguments defined!" . PHP_EOL;
    exit(1);
}

// EE Shop
if (isset($argv[3])) {
    oxRegistry::getConfig()->setShopId($argv[3]);
}

// import
$soxId = $argv[1];
/** @var $oImportConfig d3importconfig */
$oImportConfig = oxNew("d3importconfig");

if (false == $oImportConfig->load($soxId)) {
    echo $getD3ImportTimestamp() . "The import profile with id '$soxId' could not be loaded. Please check your import configuration." . PHP_EOL;
    exit(1);
}
$oImportConfig->overwriteImportTicker(0);

/** @var d3_d3importer_controllers_import_article $articleImport */
$articleImport = oxNew('d3_d3importer_controllers_import_article', $oImportConfig);
echo $getD3ImportTimestamp() . "Starting database article import..." . PHP_EOL;
$articleImport->import(0, 0);

$oDB = oxDb::getDb();
echo $getD3ImportTimestamp() . "Imported: {$oDB->getOne("select count(oxid) from oxarticles where d3importflag = 'IMPORTED'")} articles" . PHP_EOL;
echo $getD3ImportTimestamp() . "Updated: {$oDB->getOne("select count(oxid) from oxarticles where d3importflag = 'UPDATED'")} articles" . PHP_EOL;

$aViewData                = array();
$aViewData["iFailImport"] = $articleImport->getFailImport();
$aViewData["blEOF"]       = $articleImport->isEndOfFile();
$aViewData["iFilePos"]    = $articleImport->getFilePointerPosition();
$aViewData["iLinePos"]    = $articleImport->getActualLinePosition();

// delete or inactive
if (isset($argv[2])) {
    $sAction = $argv[2];
    if ($sAction == 'delete' || $sAction == 'inactive') {
        $articleImport->afterImport($sAction, 9999999999);
    }
}

if ($aViewData['iFailImport']) {
    echo $getD3ImportTimestamp() . oxRegistry::getLang()->translateString("D3_IMPORTER_FAILIMPORT_{$aViewData['iFailImport']}") . PHP_EOL;
    exit(2);
}

// picture import
echo $getD3ImportTimestamp() . 'starting picture import.' . PHP_EOL;
/** @var $oPictureImporter d3pictureimport */
$oPictureImporter = oxNew("d3pictureimport", $oImportConfig);
$oPictureImporter->setIsCronJob();
$oPictureImporter->setMaxImportCount(9999999999);
$oPictureImporter->setMaxPictureCount(9999999999);

$oPictureImporter->importExternPictures();
echo $getD3ImportTimestamp() . "Downloaded: {$oPictureImporter->numberOfExternImportedPictures} pictures" . PHP_EOL;
// ToDo for D3: $oPictureImporter->ScanPictureDir() only returns a value if failed at the moment...
echo $getD3ImportTimestamp() . "Reading picture directory... {$oPictureImporter->scanPictureDir()}"  . PHP_EOL;
$oPictureImporter->import();
if ($oPictureImporter->getConfigFailure() != 0) {
    echo $getD3ImportTimestamp() . "Config failure: {$oPictureImporter->getConfigFailure()}." . PHP_EOL;
}

echo $getD3ImportTimestamp() . "Handled: {$oPictureImporter->getActualImportCounter()} Pictures" . PHP_EOL;
exit();
